package com.ruoyi.frequency.orderpanorama.service;

import java.util.List;
import com.ruoyi.frequency.orderpanorama.entity.OrderPanorama;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 订单和3D链接关联Service接口
 * 
 * @author zj
 * @date 2023-10-13
 */
public interface OrderPanoramaService extends IService<OrderPanorama>
{
    /**
     * 查询订单和3D链接关联
     * 
     * @param id 订单和3D链接关联主键
     * @return 订单和3D链接关联
     */
    public OrderPanorama selectOrderPanoramaById(Long id);

    /**
     * 查询订单和3D链接关联列表
     * 
     * @param orderPanorama 订单和3D链接关联
     * @return 订单和3D链接关联集合
     */
    public List<OrderPanorama> selectOrderPanoramaList(OrderPanorama orderPanorama);

    /**
     * 新增订单和3D链接关联
     * 
     * @param orderPanorama 订单和3D链接关联
     * @return 结果
     */
    public int insertOrderPanorama(OrderPanorama orderPanorama);

    /**
     * 修改订单和3D链接关联
     * 
     * @param orderPanorama 订单和3D链接关联
     * @return 结果
     */
    public int updateOrderPanorama(OrderPanorama orderPanorama);

    /**
     * 批量删除订单和3D链接关联
     * 
     * @param ids 需要删除的订单和3D链接关联主键集合
     * @return 结果
     */
    public int deleteOrderPanoramaByIds(Long[] ids);

    /**
     * 删除订单和3D链接关联信息
     * 
     * @param id 订单和3D链接关联主键
     * @return 结果
     */
    public int deleteOrderPanoramaById(Long id);
}
